Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Cloud Map.

Actions, resources, and condition keys for AWS Cloud Map - Service Authorization Reference

# Actions, resources, and condition keys for AWS Cloud Map

AWS Cloud Map (service prefix: `servicediscovery` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS Cloud Map
- Resource types defined by AWS Cloud Map
- Condition keys for AWS Cloud Map

## Actions defined by AWS Cloud Map

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateHttpNamespace | Grants permission to create an HTTP namespace | Write |  | aws:TagKeys aws:RequestTag/${TagKey} |
CreatePrivateDnsNamespace | Grants permission to create a private namespace based on DNS, which will be visible only inside a specified Amazon VPC | Write |  | aws:TagKeys aws:RequestTag/${TagKey} |
CreatePublicDnsNamespace | Grants permission to create a public namespace based on DNS, which will be visible on the internet | Write |  | aws:TagKeys aws:RequestTag/${TagKey} |
CreateService | Grants permission to create a service | Write | namespace* |  |
| servicediscovery:NamespaceArn aws:TagKeys aws:RequestTag/${TagKey} |
DeleteNamespace | Grants permission to delete a specified namespace | Write | namespace* |  |
DeleteService | Grants permission to delete a specified service | Write | service* |  |
DeregisterInstance | Grants permission to delete the records and the health check, if any, that Amazon Route 53 created for the specified instance | Write | service* |  |
| servicediscovery:ServiceArn |
DiscoverInstances | Grants permission to discover registered instances for a specified namespace and service | Read |  | servicediscovery:NamespaceName servicediscovery:ServiceName |
DiscoverInstancesRevision | Grants permission to discover the revision of the instances for a specified namespace and service | Read |  | servicediscovery:NamespaceName servicediscovery:ServiceName |
GetInstance | Grants permission to get information about a specified instance | Read |  | servicediscovery:ServiceArn |
GetInstancesHealthStatus | Grants permission to get the current health status (Healthy, Unhealthy, or Unknown) of one or more instances | Read |  | servicediscovery:ServiceArn |
GetNamespace | Grants permission to get information about a namespace | Read | namespace* |  |
GetOperation | Grants permission to get information about a specific operation | Read |  |  |
GetService | Grants permission to get the settings for a specified service | Read | service* |  |
ListInstances | Grants permission to get summary information about the instances that were registered with a specified service | Read |  | servicediscovery:ServiceArn |
ListNamespaces | Grants permission to get information about the namespaces | Read |  |  |
ListOperations | Grants permission to list operations that match the criteria that you specify | List |  |  |
ListServices | Grants permission to get settings for all the services that match specified filters | Read |  |  |
ListTagsForResource | Grants permission to lists tags for the specified resource | Read |  |  |
RegisterInstance | Grants permission to register an instance based on the settings in a specified service | Write | service* |  |
| servicediscovery:ServiceArn |
TagResource | Grants permission to add one or more tags to the specified resource | Tagging |  | aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Grants permission to remove one or more tags from the specified resource | Tagging |  | aws:TagKeys aws:RequestTag/${TagKey} |
UpdateHttpNamespace | Grants permission to update the settings for a HTTP namespace | Write | namespace* |  |
UpdateInstanceCustomHealthStatus | Grants permission to update the current health status for an instance that has a custom health check | Write |  | servicediscovery:ServiceArn |
UpdatePrivateDnsNamespace | Grants permission to update the settings for a private DNS namespace | Write | namespace* |  |
UpdatePublicDnsNamespace | Grants permission to update the settings for a public DNS namespace | Write | namespace* |  |
UpdateService | Grants permission to update the settings in a specified service | Write | service* |  |

## Resource types defined by AWS Cloud Map

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
namespace | `arn:$ { Partition}:servicediscovery:$ { Region}:$ { Account}:namespace/$ { NamespaceId}` | aws:ResourceTag/${TagKey}
service | `arn:$ { Partition}:servicediscovery:$ { Region}:$ { Account}:service/$ { ServiceId}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS Cloud Map

AWS Cloud Map defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters actions based on the tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters actions based on the tags associated with the resource | String
aws:TagKeys | Filters actions based on the tag keys that are passed in the request | ArrayOfString
servicediscovery:NamespaceArn | Filters access by specifying the Amazon Resource Name (ARN) for the related namespace | String
servicediscovery:NamespaceName | Filters access by specifying the name of the related namespace | String
servicediscovery:ServiceArn | Filters access by specifying the Amazon Resource Name (ARN) for the related service | String
servicediscovery:ServiceName | Filters access by specifying the name of the related service | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.